@@ -27,7 +27,11 @@ module Cinch
     # @param [Boolean] notice Use NOTICE instead of PRIVMSG?
     # @return [void]
     # @see #safe_msg
-    def msg(text, notice = false)
+    # @note The aliases `msg` and `privmsg` are deprecated and will be
+    #   removed in a future version.
+    def send(text, notice = false)
+      # TODO deprecate `notice` argument, put splitting into own
+      # method
       text = text.to_s
       split_start = @bot.config.message_split_start || ""
       split_end   = @bot.config.message_split_end   || ""
@@ -58,25 +62,55 @@ module Cinch
         end
       end
     end
-    alias_method :send, :msg
-    alias_method :privmsg, :msg
+    alias_method :msg, :send # deprecated
+    alias_method :privmsg, :send # deprecated
+    undef_method(:msg) # yardoc hack
+    undef_method(:privmsg) # yardoc hack
 
-    # Like {#msg}, but remove any non-printable characters from
+    # @deprecated
+    def msg(*args)
+      Cinch::Utilities::Deprecation.print_deprecation("2.2.0", "Target#msg", "Target#send")
+      send(*args)
+    end
+
+    # @deprecated
+    def privmsg(*args)
+      Cinch::Utilities::Deprecation.print_deprecation("2.2.0", "Target#privmsg", "Target#send")
+      send(*args)
+    end
+
+    # Like {#send}, but remove any non-printable characters from
     # `text`. The purpose of this method is to send text of untrusted
     # sources, like other users or feeds.
     #
     # Note: this will **break** any mIRC color codes embedded in the
-    # string.
+    # string. For more fine-grained control, use
+    # {Helpers#Sanitize} and
+    # {Formatting.unformat} directly.
     #
-    # @return (see #msg)
-    # @param (see #msg)
-    # @see #msg
-    # @todo Handle mIRC color codes more gracefully.
-    def safe_msg(text, notice = false)
-      msg(Cinch::Utilities::String.filter_string(text), notice)
+    # @return (see #send)
+    # @param (see #send)
+    # @see #send
+    def safe_send(text, notice = false)
+      send(Cinch::Helpers.sanitize(text), notice)
     end
-    alias_method :safe_privmsg, :safe_msg
-    alias_method :safe_send, :safe_msg
+    alias_method :safe_msg, :safe_send # deprecated
+    alias_method :safe_privmsg, :safe_msg # deprecated
+    undef_method(:safe_msg) # yardoc hack
+    undef_method(:safe_privmsg) # yardoc hack
+
+    # @deprecated
+    def safe_msg(*args)
+      Cinch::Utilities::Deprecation.print_deprecation("2.2.0", "Target#safe_msg", "Target#safe_send")
+      send(*args)
+    end
+
+    # @deprecated
+    def safe_privmsg(*args)
+      Cinch::Utilities::Deprecation.print_deprecation("2.2.0", "Target#safe_privmsg", "Target#safe_send")
+      send(*args)
+    end
+
 
     # Like {#safe_msg} but for notices.
     #
@@ -84,7 +118,6 @@ module Cinch
     # @param (see #safe_msg)
     # @see #safe_notice
     # @see #notice
-    # @todo (see #safe_msg)
     def safe_notice(text)
       safe_msg(text, true)
     end
@@ -103,14 +136,15 @@ module Cinch
     # untrusted sources, like other users or feeds.
     #
     # Note: this will **break** any mIRC color codes embedded in the
-    # string.
+    # string. For more fine-grained control, use
+    # {Helpers#Sanitize} and
+    # {Formatting.unformat} directly.
     #
     # @param (see #action)
     # @return (see #action)
     # @see #action
-    # @todo Handle mIRC color codes more gracefully.
     def safe_action(text)
-      action(Cinch::Utilities::String.filter_string(text))
+      action(Cinch::Helpers.Sanitize(text))
     end
 
     # Send a CTCP to the target.
@@ -134,7 +168,7 @@ module Cinch
       self == other
     end
 
-    # @param [Target, String]
+    # @param [Target, String] other
     # @return [-1, 0, 1, nil]
     def <=>(other)
       casemapping = @bot.irc.isupport["CASEMAPPING"]
